
The tree sequence toolkit.

Tskit is a cross-platform library for the storage and analysis of large-scale
genetic genealogy and variation data.
Please see the `documentation <https://tskit.dev/tskit/docs/stable/>`_
for further details.

Tskit is highly portable, and provides a number of
`installation options <https://tskit.dev/tskit/docs/stable/installation.html>`_.
